@@ -1,25 +1,15 @@
 {- arch-tag: MIME Types main file
-Copyright (C) 2004-2005 John Goerzen <jgoerzen@complete.org>
+Copyright (c) 2004-2011 John Goerzen <jgoerzen@complete.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
+All rights reserved.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+For license and copyright information, see the file LICENSE
 -}
 
 {- |
    Module     : Data.MIME.Types
-   Copyright  : Copyright (C) 2004-2005 John Goerzen
-   License    : GNU GPL, version 2 or above
+   Copyright  : Copyright (C) 2004-2011 John Goerzen
+   License    : BSD3
 
    Maintainer : John Goerzen <jgoerzen@complete.org>
    Stability  : provisional
@@ -45,7 +35,8 @@ module Data.MIME.Types (-- * Creating Lookup Objects
 where
 
 import qualified Data.Map as Map
-import Monad
+import qualified Control.Exception (try, IOException)
+import Control.Monad
 import System.IO
 import System.IO.Error
 import System.IO.Utils
@@ -199,9 +190,9 @@ readSystemMIMETypes mtd =
     let tryread :: MIMETypeData -> String -> IO MIMETypeData
         tryread inputobj filename =
             do
-            fn <- try (openFile filename ReadMode)
+            fn <- Control.Exception.try (openFile filename ReadMode)
             case fn of
-                    Left _ -> return inputobj
+                    Left (_ :: Control.Exception.IOException) -> return inputobj
                     Right h -> do
                                x <- hReadMIMETypes inputobj True h
                                hClose h
